==> jc-1.4.0.tar.gz: soot/grimp/internal/GIdentityStmt.h <==
// public class soot.grimp.internal.GIdentityStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 14819393b9272047 soot_grimp_internal_GIdentityStmt
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class b38b5e2548c0bae9 soot_jimple_internal_JIdentityStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JIdentityStmt

#include "soot/jimple/internal/JIdentityStmt.h"

#ifndef _JC_soot_grimp_internal_GIdentityStmt_H_
#define _JC_soot_grimp_internal_GIdentityStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GIdentityStmt$sub_refs	_jc_soot_grimp_internal_GIdentityStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs	_jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$refs	_jc_soot_grimp_internal_GIdentityStmt$refs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$nonrefs	_jc_soot_grimp_internal_GIdentityStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$object	_jc_soot_grimp_internal_GIdentityStmt$object;

typedef const struct _jc_soot_grimp_internal_GIdentityStmt$vmethods	_jc_soot_grimp_internal_GIdentityStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GIdentityStmt$vtable	_jc_soot_grimp_internal_GIdentityStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GIdentityStmt$vtype	_jc_soot_grimp_internal_GIdentityStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GIdentityStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GIdentityStmt$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GIdentityStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GIdentityStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GIdentityStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GIdentityStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GIdentityStmt$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GIdentityStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JIdentityStmt$vmethods	soot_jimple_internal_JIdentityStmt;
	_jc_soot_grimp_internal_GIdentityStmt$vmethods	soot_grimp_internal_GIdentityStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GIdentityStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GIdentityStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GIdentityStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GIdentityStmt$refs {
    _jc_soot_grimp_internal_GIdentityStmt$sub_refs	soot_grimp_internal_GIdentityStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_refs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GIdentityStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs	soot_grimp_internal_GIdentityStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GIdentityStmt$object {
	_jc_soot_grimp_internal_GIdentityStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GIdentityStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GIdentityStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GIdentityStmt$vtype _jc_soot_grimp_internal_GIdentityStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GIdentityStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GIdentityStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GIdentityStmt_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GIdentityStmt.h <==
// public class soot.grimp.internal.GIdentityStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 14819393b9272047 soot_grimp_internal_GIdentityStmt
// @dep_class edca39c912a872fb soot_jimple_internal_AbstractDefinitionStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class b38b5e2548c0bae9 soot_jimple_internal_JIdentityStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JIdentityStmt

#include "soot/jimple/internal/JIdentityStmt.h"

#ifndef _JC_soot_grimp_internal_GIdentityStmt_H_
#define _JC_soot_grimp_internal_GIdentityStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GIdentityStmt$sub_refs	_jc_soot_grimp_internal_GIdentityStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs	_jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$refs	_jc_soot_grimp_internal_GIdentityStmt$refs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$nonrefs	_jc_soot_grimp_internal_GIdentityStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GIdentityStmt$object	_jc_soot_grimp_internal_GIdentityStmt$object;

typedef const struct _jc_soot_grimp_internal_GIdentityStmt$vmethods	_jc_soot_grimp_internal_GIdentityStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GIdentityStmt$vtable	_jc_soot_grimp_internal_GIdentityStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GIdentityStmt$vtype	_jc_soot_grimp_internal_GIdentityStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GIdentityStmt$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GIdentityStmt$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GIdentityStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GIdentityStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GIdentityStmt$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GIdentityStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GIdentityStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GIdentityStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_AbstractDefinitionStmt$vmethods	soot_jimple_internal_AbstractDefinitionStmt;
	_jc_soot_jimple_internal_JIdentityStmt$vmethods	soot_jimple_internal_JIdentityStmt;
	_jc_soot_grimp_internal_GIdentityStmt$vmethods	soot_grimp_internal_GIdentityStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GIdentityStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GIdentityStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GIdentityStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GIdentityStmt$refs {
    _jc_soot_grimp_internal_GIdentityStmt$sub_refs	soot_grimp_internal_GIdentityStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_refs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_refs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GIdentityStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_AbstractDefinitionStmt$sub_nonrefs	soot_jimple_internal_AbstractDefinitionStmt;
    _jc_soot_jimple_internal_JIdentityStmt$sub_nonrefs	soot_jimple_internal_JIdentityStmt;
    _jc_soot_grimp_internal_GIdentityStmt$sub_nonrefs	soot_grimp_internal_GIdentityStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GIdentityStmt$object {
	_jc_soot_grimp_internal_GIdentityStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GIdentityStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GIdentityStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GIdentityStmt$vtype _jc_soot_grimp_internal_GIdentityStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GIdentityStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GIdentityStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GIdentityStmt_H_ */
